#!/usr/bin/env python
import unittest
import copy
import json
import os
import manifest
from intervention_test import TestIntervention

import emodpy_tbhiv.interventions.cd4diag as cd4
import emod_api.campaign as camp


class Testcd4diag(TestIntervention):
    """
    Test CD4Diagnostic intervention
    """
    def test(self):
        super().trigger_treatment_list_test(cd4.CD4Diag, "CD4Diagnostic", "camp_cd4diag.json", True)

    def test_all(self):
        camp.schema_path = self.schema
        trigger_treatment_list = ['infected']
        event_200 = 'Below200'
        event_350 = 'Below350'
        event_500 = 'Below500'
        event_above_500 = 'Above500'
        start_day = 1
        duration = 20
        property_restrictions_list = ['Demo: 3']
        expected_property_restrictions_list = copy.deepcopy(property_restrictions_list)
        nodeIDs = []
        black_period = 0
        black_trigger = 'Blackout'
        event_name = 'CD4 Diagnostic'
        event = cd4.CD4Diag(camp, trigger_treatment_list, event_200, event_350, event_500, event_above_500, start_day,
                            duration, property_restrictions_list, nodeIDs, black_period, black_trigger, event_name)
        camp.add(event, first=True)
        camp_filename = os.path.join(self.output, "camp_cd4diag.json")
        manifest.delete_existing_file(camp_filename)
        camp.save(camp_filename)
        self.assertTrue(os.path.isfile(camp_filename))

        with open(camp_filename, 'r') as file:
            camp_file = json.load(file)
        ecc = camp_file["Events"][0]["Event_Coordinator_Config"]
        ic = ecc["Intervention_Config"]
        intervention = ic["Actual_IndividualIntervention_Config"]

        # ToDo: assert on the intervention

        self.assertListEqual(ic["Property_Restrictions"], [property_restrictions.replace(" ", "") for
                                                           property_restrictions in
                                                           expected_property_restrictions_list])
        self.assertEqual(ic["Duration"], duration)
        # self.assertEqual(ic["Blackout_Period"], black_period)
        # self.assertEqual(ic["Blackout_Event_Trigger"], black_trigger)
        self.assertEqual(camp_file["Events"][0]["Start_Day"], start_day)

    def test_new_intervention_as_file(self, intervention_class_name='CD4Diagnostic'):
        camp_filename = os.path.join(self.output, 'camp_cd4diag_as_file.json')
        super().new_intervention_as_file_test(cd4, camp_filename, intervention_class_name, is_multi=True)


if __name__ == '__main__':
    unittest.main()

